Cloud Native Computing Foundation (“CNCF”) Charter

The Linux Foundation

Effective Nov 6 2015 / Updated September 26, 2024

#### 1. Mission of the Cloud Native Computing Foundation.

The Foundation’s mission is to make cloud native computing ubiquitous. The CNCF Cloud Native Definition v1.0 says:

Cloud native technologies empower organizations to build and run scalable applications in modern, dynamic environments such as public, private, and hybrid clouds. Containers, service meshes, microservices, immutable infrastructure, and declarative APIs exemplify this approach.

These techniques enable loosely coupled systems that are resilient, manageable, and observable. Combined with robust automation, they allow engineers to make high-impact changes frequently and predictably with minimal toil.

The Cloud Native Computing Foundation seeks to drive adoption of this paradigm by fostering and sustaining an ecosystem of open source, vendor-neutral projects. We democratize state-of-the-art patterns to make these innovations accessible for everyone.

#### 2. Role of the CNCF.

The CNCF will serve a role in the open source community responsible for:

-	(a) Stewardship of the projects

	-	i. Ensuring that the technologies are available to the community and free of partisan influence

	-	ii. Ensure that the technologies’ brand (trademark and logo) is being cared for and used appropriately by members of the community, with a specific emphasis on uniform user experience and high levels of application compatibility

-	(b) Fostering the growth and evolution of the ecosystem

	-	i. Evaluating which additional technologies should be added to meet the vision of cloud native applications, and working to encourage the community to deliver them, and integrate them if and only if they advance the general agenda

	-	ii. Providing a way to foster common technical standards across the various pieces

-	(c) Promotion of the underlying technologies, and approach to application definition and management, including: events and conferences, marketing (SEM, direct marketing), training courses and developer certification

-	(d) Serve the community by making the technology accessible and reliable.

#### 3. Values.

The CNCF community will strive to adhere to the following principles:

-	(a) Trusted. We guide projects to build trust with adopters and users, balancing quality and sustainability with velocity.

-	(b) Open. Openness and transparency are foundational: our technical work must be available to all according to these values. Our community, processes, and decisions are transparent, visible, and discoverable.

-	(c) Neutral. We avoid influence, biased behavior, “pay-to-play” decision-making, and other activities that favor one project, individual, or organization over another. We operate independently of specific partisan interests and biases, considerate of global and international interests. 

-	(d) Platform agnostic. We have an explicit bias toward projects and specifications developed to be platform agnostic such that they can be implemented on a variety of platforms, architectures, clouds, and operating systems.

-	(e) Accelerated adoption. We enable progress at high velocity to support aggressive adoption of quality, sustainable, and secure projects by users.

-	(f) Project diversity and scalability. We support diverse projects, from experimentation and small developer-centric environments to the scale of enterprises and service providers, with robust maturity.

-	(g) Experimentation and innovation. We support projects that address new and existing problem spaces in keeping with the cloud native definition, fostering project innovation for a variety of solutions to meet the diverse needs of adopters and users. We remain aware of innovation in the space and may invite projects to become a part of the CNCF ecosystem, to succeed or to learn.

-	(h) Sustainability. We encourage sustainability, growth, and health of maintainers, contributors, and byproducts to foster succession and support of the CNCF vision for the long term, with focus to reduce additional burden and toil on maintainers. We consider the future needs of cloud native impact on a global scale, to use resources efficiently for all projects.

-	(i) Inclusive unity. Whether operating the Foundation, serving on a board or committee, contributing to a review, or managing a project, we are unified in the advancement of cloud native inclusivity, enabling our collective technical vision to be achievable. We accept all contributors based on the merit of their contributions and conduct.


#### 4. Membership.

The CNCF shall be composed of Platinum, Gold, Silver, End User, Academic and Non-Profit member participants. All member applications will be reviewed by the Linux Foundation, who will decide whether that applicant is to be classified as an end user, academic/non-profit, or vendor for purposes of CNCF membership.

-	(a) Platinum members shall be entitled to:

	-	i. Appoint one (1) representative to the CNCF Governing Board.

	-	ii. Appoint one (1) representative as a voting member in any subcommittees or activities of the Governing Board.

	-	iii. Enjoy most prominent placement in displays of membership including on the website.

	-	iv. If the member is also an approved End User, appoint one (1) representative to the End User TAB.

-	(b) Gold members shall be entitled to:

	-	i. Appoint one (1) representative to the CNCF Governing Board per every five (5) Gold members, up to three (3) maximum Gold representatives.

	-	ii. If the members are also approved End Users, elect one (1) representative to the End User TAB for every five (5) Gold End User members, up to three (3) maximum Gold representatives.

-	(c) Silver members shall be entitled to:

	-	i. Appoint one (1) representative to the CNCF Governing Board per every ten (10) Silver members, up to three (3) maximum Silver representatives.

	-	ii. If the members are also approved End Users, elect one (1) representative to the End User TAB for every ten (10) Silver End User members, up to three (3) maximum Silver representatives.

-	(d) Academic and Non-Profit members: The Academic and Non-Profit category of participation is limited to academic and non-profit institutions respectively and requires approval by the Governing Board. Academic and Non-Profit members shall be entitled to identify their organization as members supporting the mission of CNCF and any other rights or benefits as determined by the Governing Board.

#### 5. Governing Board

-	(a) The CNCF Governing Board will be responsible for marketing and other business oversight and budget decisions for the CNCF. The Governing Board does not make technical decisions for the CNCF, other than working with the TOC to set the overall scope for the CNCF as described in the cloud native definition from Section 1.

-	(b) The Governing Board will address business matters including:

	-	i. adopting the overall scope for the CNCF in consultation with the TOC;

	-	ii. defining and enforcing policy regarding the use of the trademarks and copyrights of the foundation;

	-	iii. directing marketing, including evangelism, events and ecosystem engagement;

	-	iv. creating and executing a brand compliance program, if desired;

	-	v. overseeing operations and qualification efforts; and

	-	vi. fundraising and financial governance overall;

-	(c) Composition – the Governing Board voting members shall consist of Member Representatives and Technical Community Representatives:

	-	i. Member Representatives consist of:

		-	a. one representative appointed from each Platinum member; and
		-	b. the Gold and Silver member elected representatives (if any)

	-	ii. Technical Community Representatives consist of:

		-	a. the TOC Chair,

		-	b. the End User TAB Chair, and

		-	c. two Committers elected from the CNCF Projects under a process approved by the then-serving Governing Board.

	-	iii. The Governing Board may extend a Platinum membership at the Silver Membership Scale rates on a year-by-year basis for up to 5 years to startup companies with revenues less than \$50 million that are deemed strategic technology contributors by the Governing Board.

	-	iv. Only one person from a group of Related Companies may serve as a Member Representative. Only one person from a group of Related Companies may serve as a Technical Community Representative.

-	(d) Responsibilities:

	-	i. approve a budget directing the use of funds raised from all sources of revenue to be used for technical, marketing or community investments that advance the mission of the CNCF;

	-	ii. elect a Chair of the Governing Board to preside over meetings, authorize expenditures approved by the budget and manage any day-to-day operations;

		-	a. The Chair of the Governing Board shall be elected to a two-year term. The Executive Director may call a special election as needed. 

		-	b. The Chair of the Governing Board shall be elected to the position and a Condorcet vote shall be run using the Condorcet-IRV method through the Cornell online service (https://civs.cs.cornell.edu/).

	-	iii. vote on decisions or matters before the Governing Board;

	-	iv. define and enforce policy regarding intellectual property (copyright, patent or trademark) of the foundation;

	-	v. direct marketing and evangelism efforts through events, press and analyst outreach, web, social and other marketing efforts;

	-	vi. oversee operations and qualification efforts;

	-	vii. establish and oversee any committees created to drive the mission of CNCF;

	-	viii. establish and execute a brand compliance program, if any, based on the CNCF requirements, which may include a certification test, to use the brand marks established by the TOC;

	-	ix. adopt guidelines or a policy for use of the trademark; and

	-	x. and provide financial governance overall.

-	(e) The revenues collected by the project shall be used for the following purposes:

	-	i. The marketing, promotion and expansion of deployment and use of the “Included in CNCF” projects.
	-	ii. The staffing of key resources to build, run and manage project productivity infrastructure.
	-	iii. The promotion of container-based computing principles as outlined and implementation thereof via the CNCF’s projects.

#### 6. Technical Oversight Committee (“TOC”)

-	(a) Mandate. The TOC is expected to facilitate driving neutral consensus for:

	-	i. defining and maintaining the technical vision for the Cloud Native Computing Foundation,

	-	ii. approving new projects within the scope for CNCF set by the Governing Board, and creating a conceptual architecture for the projects,

	-	iii. aligning projects, removing or archiving projects,

	-	iv. accepting feedback from the end user committee and mapping to projects,

	-	v. aligning interfaces to components under management (code reference implementations before standardizing), and

	-	vi. defining common practices to be implemented across CNCF projects, if any.

-	(b) Composition

	-	i. The TOC shall be composed of eleven (11) members.

	-	ii. TOC members elected are expected to cover key technical domains: container technologies, operating systems, technical operations, distributed systems, user level application design, etc.

	-	iii. The Governing Board shall elect six (6) TOC members, the End User Participants shall elect two (2) TOC members, the non-sandbox project maintainers shall elect one (1) TOC member, and the TOC members shall elect an additional two (2) TOC members. Each group is defined as a Selecting Group.

	-	iv. If more than two (2) TOC members would be from the same group of Related Companies, either at the time of election or from a later job change, they will jointly decide who should step down, or if there is no agreement, random lots shall be drawn.

-	(c) Operating Model

	-	i. The TOC shall select a Chair of the TOC to set agendas and call meetings of the TOC.

	-	ii. The TOC is expected to meet regularly face-to-face to discuss key topical issues.

	-	iii. The TOC may meet virtually as needed to discuss emerging issues. Issues may be raised for TOC review by:

		-	a. any TOC member,

		-	b. any Governing Board member,

		-	c. a maintainer or top level project leader in a CNCF project established under Section 9(b)(i),

		-	d. the CNCF Executive Director, or

		-	e. a majority vote of the End User TAB.

	-	iv. Transparency. The TOC shall hold regular open TOC meetings and all project-related decisions shall be made in those meetings, on a public mailing list, or on public issues.

	-	v. Simple TOC issues may be resolved by short discussion and simple majority vote. TOC discussions may be over email or at a meeting of the TOC.

	-	vi. After a review of the opinions and optional virtual discussion/debate options are identified, seeking consensus and taken to vote if necessary.

	-	vii. The intent is for the TOC to find a path to consensus within the TOC and community. TOC decisions at meetings meeting quorum requirements shall pass with a vote greater than 50% of TOC members present.

	-	viii. TOC meetings shall require a quorum of two-thirds of the TOC total members to take a vote or make any decision. If a TOC meeting fails to meet the quorum requirement, discussions may proceed, however there shall be no voting or decisions.

	-	ix. TOC decisions may be made electronically without a meeting, but to pass a vote shall require as many votes as would be needed to achieve quorum in a meeting. During an electronic vote, if any two (2) TOC members request a meeting to discuss the decision, the electronic vote in process shall end without effect, and a new vote may be initiated after the meeting to discuss the decision has completed.

-	(d) Criteria for Nomination. Nominees for the TOC shall:

	-	i. commit that they have the available bandwidth to make the time to invest in the CNCF TOC,

	-	ii. demonstrate an advanced level of professional experience as leaders with demonstrated technical expertise in the scope of CNCF,

	-	iii. demonstrate seniority sufficient to access additional staff or community members to assist in their TOC preparations, and
    
    -   iv. operate neutrally in discussions and put the goals and success of CNCF in balance with corporate objectives or any particular project in CNCF.

-	(e) Process for TOC Member Nominations and Election

    -   i. Nominations: Each individual in a Selecting Group may nominate up to two (2) people, at most one (1) of whom may be from the same group of Related Companies. Each nominee must agree to participate prior to being added to the nomination list.

		-	a. A nomination requires a maximum one (1) page nomination pitch which should include the nominee's name, contact information and supporting statement identifying the nominee's experience in CNCF domains.

		-	b. The Governing Board shall determine the process and timeline for the nominations, qualification and election of TOC members.

		-	c. A minimum of 14 calendar days shall be reserved for an Evaluation Period whereby TOC nominees may be contacted by members of the Governing Board and TOC.

	-	ii. Qualification: After the Evaluation Period, the Governing Board and the TOC members shall vote on each nominee individually to validate that the nominee meets the qualification criteria. A valid vote shall require at least 50% participation. Nominees passing with over 50% shall be Qualified Nominees.

	-	iii. Elections: If the number of Qualified Nominees is equal to or less than the number of TOC seats available to be elected, the Qualified Nominees shall be approved after the nomination period has closed. If there are more Qualified Nominees than open TOC seats available for election, then the Selecting Group shall elect the TOC members via a Condorcet vote. A Condorcet vote shall be run using the Condorcet-IRV method through the Cornell online service ([*https://civs.cs.cornell.edu/*](https://civs.cs.cornell.edu/)).

    -   iv. TOC-Selected Seats: TOC-Selected TOC members may nominate and qualify but not vote when their seat is up for election.

	-	v. Retries. If there are fewer Qualified Nominees than open TOC seats available for election by the Selecting Group, the group shall initiate another round of nominations.

-	(f) Constraints

	-	i. TOC Members shall serve two-year, staggered terms.

	-	ii. TOC members may be removed by a two-thirds vote of the other TOC members, with the impacted individual ineligible to participate in the vote.

	-	iii. Any TOC member that misses three (3) consecutive meetings shall be automatically suspended from eligibility to vote until having attended two meetings consecutively. For avoidance of doubt, the suspended TOC member shall be eligible to vote in the second consecutive meeting.

	-	iv. The TOC agenda will be set by the TOC. However, it is expected that TOC discussions and decisions will cover:

		-	a. assessing technologies to include in CNCF

		-	b. defining acceptance criteria for new technologies to include in CNCF

		-	c. defining process to ratify a contributed technology as a standard API

		-	d. identifying immediate gaps that require further investigation

#### 7. End User Community

-	(a) End User Members in CNCF shall be entitled to coordinate and drive activities important to users of CNCF as consumers for which CNCF was designed. Any End User organization that is a CNCF Member or a CNCF End User Supporter(each an “End User Participant) may participate. The End User Participants are expected to help provide input to the Technical Advisory Board and CNCF community on topics relevant to users.

-	(b) End User Community Members will be approved by CNCF.

#### 8. End User Technical Advisory Board (“End User TAB”).

-	(a) Purpose and Duties: The End User TAB will serve as the voice of End Users in the CNCF community, advance topics of concern to End Users, and raise awareness about the needs and perspectives of end users. More specifically, the goals and responsibilities of the End User TAB are to:

	-	i. Facilitate communication among the end user community and other governing bodies of CNCF.

	-	ii. Provide advice, feedback, and recommendations to the TOC on areas of mutual concern, including the state and technical direction of the cloud native ecosystem, and identification of technical challenges and gaps.

	-	iii. Improve visibility into end user adoption of CNCF projects.

	-	iv. Provide feedback on CNCF projects' usability, reliability, and performance.

	-	v. Review and approve publication of reference architectures.

	-	vi. Advise on CNCF End User Radar tools and techniques.

	-	vii. Provide oversight into End User Groups and End User Special Interest Groups.					

-	(b) Composition and Selection: The End User TAB shall be composed of seven (7) or more representatives from End User Participants selected in the following manner:

	-	i. one representative appointed by each Platinum End User member.

	-	ii. the representatives (if any) elected by the Gold and Silver End User members.

	-	iii. at least three (3) representatives elected by the End User Participants at large. The number of at large End User Participant representatives shall generally be three (3), but may be increased either (A) by vote of the then-existing End User TAB or (B) automatically to the extent necessary to ensure the minimum size described in section 8(a) of this charter is met (given the number of Platinum, Gold, and Silver End User member representatives).

	-	iv. one (1) to two (2) TOC members designated by the TOC, each of whom must be employed by an End User Participant.

	-	v. one (1) or more additional End User Participant representatives may be invited to serve on the End User TAB if approved by a majority of the then-existing members of the End User TAB.						

-	(c) Terms: Each elected or invited member of the End User TAB shall serve a term of approximately two (2) years, except that approximately half of the elected members of the End User TAB resulting from the first election shall serve a one (1) year term in order to facilitate staggered terms. The initial End User TAB shall determine which of the initial members shall serve a one (1) year term and which shall serve a two (2) year term.

-	(d) Termination: An End User TAB member's participation shall cease before the expiration of their term if they resign, are removed, or they cease to be employed by the End User organization that employed them at the time they were elected. There are no limits on the number of terms that an individual can serve. The End User TAB may, by supermajority vote of at least two-thirds of the End User TAB members who do not have conflicts of interest, remove an End User TAB member who is not fulfilling their duties or is not complying with the policies of CNCF or the End User TAB.

-	(e) Vacancies: In the event of a vacancy due to an End User TAB member's employer ceasing to be an End User Participant, the End User TAB shall decide when to fill the vacancy and whether to fill the vacancy by election or invitation. In the event of a vacancy due to to an individual’s resignation, removal, or changing employers, the End User Participant that employed such individual at the time they were elected may designate a replacement. For the sake of continuity, in the event an individual serving on the End User TAB leaves their employer for another employer who is also an End User Participant, the remaining non-conflicted End User TAB members may, by majority vote, increase the size of the End User TAB and invite the individual to remain on the End User TAB for a duration no longer than their original term; such individual continuing to serve shall be in addition to (not in lieu of) the individual’s prior employer’s right to designate a replacement.

-	(f) Alternates: Any End User Participant with an employee serving on the End User TAB may designate an alternate who may (a) attend meetings in listen-only mode when the primary representative is present and (b) speak and vote at meetings when the primary representative is not present. The TOC may also designate an alternate (who must be employed by an End User Participant) in addition to the End User TAB member(s) the TOC appoints in accordance with Section 8(d)(iv) of this charter.

-	(g) Eligibility and Criteria:

	-	i. Eligibility: Only employees of End User Participants in good standing may serve on the End User TAB.

	-	ii. Criteria: End User representatives should be nominated on operational and technical acumen. Nominees should have significant practical experience with operating cloud native infrastructure and applications including CNCF projects.

	-	iii. Maximum Representatives from a Single Organization: No more than two representatives of the same organization (not counting alternates) may serve on the End User TAB simultaneously. If, for any reason (e.g., merger or combination) more than 2 End User TAB members would be from a single organization, the organization will choose which 2 representatives will serve on the End User TAB, and the organization’s other(s) representatives shall resign from the End User TAB.				
-	The End User TAB may also focus on proactively advancing topics of concern to End Users, promoting market adoption of CNCF, hosting meetings for End Users, or advising the Governing Board.

-	(h) If the End User TAB desires, it may approve End User Groups, Special Interest Groups (“SIGs”), or subcommittees to address industry or specialized topics.

-	(i) The End User TAB input to the TOC shall be taken together with other input and feedback for the TOC to make decisions and plans. The recommendations are advisory only and at no point shall the recommendations of the End User TAB be used to order or direct any TOC or project participant toward any action or outcome.

-	(j) The End User TAB shall select a Chair of the End User TAB to set agendas, facilitate discussions, and serve as the End User TAB representative to the Governing Board. The End User TAB may, at its option, select one or two Vice Chairs.

-	(k) The End User TAB may develop policies and procedures related to nominations, elections, operations, or other matters pertaining to its purpose, scope, and activities so long as such policies and procedures are consistent with this charter.

#### 9. CNCF Projects

-	(a) It is expected that member companies, and open source community members will bring project assets to the TOC for discussion and inclusion into the CNCF. All such contributions should meet a set criteria created by the TOC and ratified by the Governing Board. The goal is to have an increasing bazaar of projects related to and that integrate with projects already accepted into the CNCF.

-	(b) Projects can be associated with the CNCF in the following 3 ways:

	-	i. Included in CNCF, under a neutral home for collaboration

		-	a. The project meets the requirements for being incuding as a CNCF project.

		-	b. The project is marketed by the CNCF as a CNCF project

		-	c. The project should be a core functional component of the CNCF solution. (e.g. such as Kubernetes, Mesos, etcd, etc.)

	-	ii. Associated with the CNCF via an API or specification

		-	a. Includes components where the CNCF may offer or enable multiple options

		-	b. The project is referred to as a component that the CNCF integrates with, not as a project hosted by the CNCF

		-	c. Integration and compliance are defined by an API or specification

		-	d. Active development on the project or component is ideally done in the upstream community

	-	iii. Used by the CNCF

		-	a. A project or component that is completely licensed under an OSI-approved open source license and is well managed and used as a component in the CNCF

		-	b. Project is not actively marketed by the CNCF,

		-	c. Active development on the project or component is ideally done in the upstream community

-	(c) Existing open source projects should continue to run through their existing technical governance structure to maintain cohesion and velocity. Projects approved by the TOC for inclusion in the CNCF will be ‘lightly’ subject to the Technical Oversight Committee.

-	(d) A standard protocol to achieve committer status shall be established across projects based on an individual’s level and duration of contribution. Maintainer status is achieved through contribution to a given project over time and validation by peer committers.

-	(e) New open source projects initiated in CNCF shall complete a project proposal template adopted by the TOC and be approved by the TOC for inclusion in CNCF. The TOC members shall be afforded sufficient time to discuss and review new project proposals. New project proposals shall include details of the roles in the project, the governance proposed for the project and identify alignment with CNCF’s role and values.

#### 10. Marketing Committee

-	(a) Composition: the Marketing Committee will be open to all members to participate. A Chair of the Marketing Committee shall be elected to develop meeting agendas, moderate discussions and help the committee progress against its goals. The Marketing Committee shall seek consensus where possible. Any issues that cannot reach a Rough Consensus in the Marketing Committee shall be referred to the Governing Board.

-	(b) Responsibilities: The Marketing Committee shall be responsible for designing, developing and executing marketing efforts on behalf of the Governing Board.

-	(c) If the Marketing Committee becomes too large to operate effectively, the Marketing Committee may choose to elect Marketing Board and delegate decision authority to the Marketing Board.

#### 11. IP Policy

-	(a) Any project that is added to the CNCF must have ownership of its trademark and logo assets transferred to the Linux Foundation or a Linux Foundation project hosting entity.

-	(b) Each project shall determine whether it will require use of an approved CNCF CLA. For projects that select to use a CLA, all code contributors will undertake the obligations set forth in the Apache contributor license agreement(s), altered only as necessary to identify CNCF or the project as the recipient of the contributions, and which shall be approved by the Governance Board. See CNCF Contributor License Agreements available at https://github.com/cncf/cla. The process for managing contributions in accordance with this policy shall be subject to Governance Board approval.

-	(c) All new inbound code contributions to the CNCF shall be (i) accompanied by a Developer Certificate of Origin sign-off ([*https://developercertificate.org*](https://developercertificate.org/)\) and (ii) made under the Apache License, Version 2.0 (available at [*https://www.apache.org/licenses/LICENSE-2.0*](https://www.apache.org/licenses/LICENSE-2.0)), such license to be in addition to, and shall not supersede, obligations undertaken under the contribution license agreement(s) provided for in (b) above.

-	(d) All outbound code will be made available under the Apache License, Version 2.0.

-	(e) All projects evaluated for inclusion in the CNCF shall be completely licensed under an OSI-approved open source license. If the license for a project included in CNCF is not Apache License, Version 2.0, approval of the Governing Board shall be required.

-	(f) All documentation will be received and made available by the CNCF under the Creative Commons Attribution 4.0 International License.

-	(g) If an alternative inbound or outbound license is required for compliance with the license for a leveraged open source project or is otherwise required to achieve the CNCF’s mission, the Governing Board may approve the use of an alternative license for inbound or outbound contributions on an exception basis.

#### 12. Antitrust Guidelines

-	(a) All members shall abide by the requirements for The Linux Foundation set forth in the Linux Foundation Antitrust Policy available at [*https://www.linuxfoundation.org/antitrust-policy*](https://www.linuxfoundation.org/antitrust-policy).

-	(b) All members shall encourage open participation from any organization able to meet the membership requirements, regardless of competitive interests. Put another way, the Governing Board shall not seek to exclude members based on any criteria, requirements or reasons other than those used for all members.

#### 13. Code of Conduct

-	(a) All participants agree to abide by The Linux Foundation Code of Conduct available at [*https://events.linuxfoundation.org/code-of-conduct*](https://events.linuxfoundation.org/code-of-conduct). The TOC may vote to adopt its own code of conduct for the CNCF community.

#### 14. Related Companies

-	(a). Definitions:

	-	i. “Subsidiaries” shall mean any entity in which a Member owns, directly or indirectly, more than fifty percent of the voting securities or membership interests of the entity in question;

	-	ii. “Related Company” shall mean any entity which controls or is controlled by a Member or which, together with a Member, is under the common control of a third party, in each case where such control results from ownership, either directly or indirectly, of more than fifty percent of the voting securities or membership interests of the entity in question; and

	-	iii. “Related Companies” are entities that are each a Related Company of a Member.

-	(b). Only the legal entity which has executed a Participation Agreement and its Subsidiaries shall be entitled to enjoy the rights and privileges of such Membership; provided, however, that such Member and its Subsidiaries shall be treated together as a single Member.

-	(c). Only one Member which is part of a group of Related Companies shall be entitled to appoint, or nominate for a membership class election, a representative on the Governing Board at one time.

-	(d) If a Member is itself a foundation, consortium, open source project, membership organization, user group or other entity that has members or sponsors, then the rights and privileges granted to such Member shall extend only to the employee-representatives of such Member, and not to its members or sponsors, unless otherwise approved by the Governing Board in a specific case from time to time.

-	(e). Memberships shall be non-transferable, non-salable and non-assignable, except that any Member may transfer its current Membership benefits and obligations to a successor to substantially all of its business and/or assets, whether by merger, sale or otherwise; provided that the transferee agrees to be bound by this Charter and the Bylaws and policies required by Linux Foundation membership.

#### 15. Budget

-	(a) The Governing Board shall approve an annual budget and never commit to spend in excess of funds raised. The budget shall be consistent with the nonprofit mission of The Linux Foundation.

-	(b) The Linux Foundation shall provide regular reports of spend levels against the budget.

#### 16. General & Administrative Expenses

-	(a) The Linux Foundation shall have custody of any fees, funds and other cash receipts.

-	(b) A General & Administrative (G&A) fee will be applied to funds raised to cover Finance, Accounting and operations. The G&A fee shall equal 9% of CNCF’s first \$1,000,000 of gross receipts and 6% of CNCF’s gross receipts over \$1,000,000.

#### 17. General Rules and Operations.

CNCF projects are required to:

-	(a) demonstrate plans and the means to coordinate with the open source project’s developer community, including on topics such as branding, logos, and other collateral that will represent the community;

-	(b) engage in a professional manner consistent with maintaining a cohesive community, while also maintaining the goodwill and esteem of The Linux Foundation in the open source software community;

-	(c) respect the rights of all trademark owners, including any branding and usage guidelines;

-	(d) engage The Linux Foundation for all press and analyst relations activities;

-	(e) upon request, provide information regarding project participation, including information regarding attendance at project-sponsored events, to The Linux Foundation;

-	(f) engage The Linux Foundation for any websites directly for the foundation; and

-	(g) operate under such rules and procedures as may from time to time be approved by the Governing Board, provided that such rules and procedures shall not be inconsistent with the purpose and policies of the Linux Foundation and shall not be detrimental to the Linux Foundation.

#### 18. Amendments

This charter may be amended by a two-thirds vote (excluding abstentions) of all Governing Board members, provided that any such amendments shall not be inconsistent with the purpose or policies of the Linux Foundation and shall not be detrimental to the Linux Foundation.
